<!-- Copyright: © 2024 Jonathan Fox
License: GNU AGPL, version 3 or later; http://www.gnu.org/licenses/agpl.html
Full source code: https://github.com/jonathanfox5/gogadget -->

- **If you prefer to watch a tutorial rather than follow a written guide, click here: [Video Tutorial](../getting_started/video_tutorial.md)**
- Installation instructions: [Installation](../getting_started/installation.md)
- Examples of some of the functions are given here: [Basic Examples](../getting_started/example_commands.md)
- An example use case of the tool (generating priming materials): [Example use case](../getting_started/example_use_case.md)
- Full written documentation of every function in the tool is available here: [Command reference](../reference/command_reference.md)
- Where to get dictionary and audio files to use in your Anki cards: [Getting resources](../getting_started/getting_resources.md)
- How to get help: [Getting Help](../misc/getting_help.md)
